# pylint: disable=import-outside-toplevel
import logging
import sys

from ..config import LoggingConfig

def disable_tqdm():
    from tqdm import tqdm
    from functools import partialmethod
    tqdm.__init__ = partialmethod(tqdm.__init__, disable=True)

def __init_logger():
    if LoggingConfig.LEVEL == "DEBUG":
        disable_tqdm()

    default_logger = logging.getLogger(LoggingConfig.NAME)
    default_logger.setLevel(LoggingConfig.LEVEL)

    default_handler = logging.StreamHandler(stream=sys.stdout)
    default_formatter = logging.Formatter('[%(levelname)s] [%(name)s] %(message)s')

    default_handler.setFormatter(default_formatter)
    default_logger.addHandler(default_handler)

    return default_logger

LOGGER = __init_logger()
